Class: Aws::SecretsManager::Types::Tag
- Inherits:
-
Struct
- Object
- Struct
- Aws::SecretsManager::Types::Tag
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-secretsmanager/types.rb
Overview
A structure that contains information about a tag.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ String
The key identifier, or name, of the tag.
-
#value ⇒ String
The string value associated with the key of the tag.
Instance Attribute Details
#key ⇒ String
The key identifier, or name, of the tag.
2297 2298 2299 2300 2301 2302 |
# File 'lib/aws-sdk-secretsmanager/types.rb', line 2297 class Tag < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The string value associated with the key of the tag.
2297 2298 2299 2300 2301 2302 |
# File 'lib/aws-sdk-secretsmanager/types.rb', line 2297 class Tag < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |